@@ -5,8 +5,9 @@ import (
 	"fmt"
 
 	"github.com/gophercloud/utils/openstack/clientconfig"
+	"github.com/pkg/errors"
+
 	"github.com/openshift/installer/pkg/asset"
-	awsconfig "github.com/openshift/installer/pkg/asset/installconfig/aws"
 	azureconfig "github.com/openshift/installer/pkg/asset/installconfig/azure"
 	gcpconfig "github.com/openshift/installer/pkg/asset/installconfig/gcp"
 	"github.com/openshift/installer/pkg/types/aws"
@@ -17,7 +18,6 @@ import (
 	"github.com/openshift/installer/pkg/types/none"
 	"github.com/openshift/installer/pkg/types/openstack"
 	"github.com/openshift/installer/pkg/types/vsphere"
-	"github.com/pkg/errors"
 )
 
 // PlatformCredsCheck is an asset that checks the platform credentials, asks for them or errors out if invalid
@@ -36,6 +36,7 @@ func (a *PlatformCredsCheck) Dependencies() []asset.Asset {
 
 // Generate queries for input from the user.
 func (a *PlatformCredsCheck) Generate(dependencies asset.Parents) error {
+	ctx := context.TODO()
 	ic := &InstallConfig{}
 	dependencies.Get(ic)
 
@@ -43,16 +44,12 @@ func (a *PlatformCredsCheck) Generate(dependencies asset.Parents) error {
 	platform := ic.Config.Platform.Name()
 	switch platform {
 	case aws.Name:
-		ssn, err := awsconfig.GetSession()
+		_, err := ic.AWS.Session(ctx)
 		if err != nil {
-			return errors.Wrap(err, "creating AWS session")
-		}
-		err = awsconfig.ValidateCreds(ssn)
-		if err != nil {
-			return errors.Wrap(err, "validate AWS credentials")
+			return err
 		}
 	case gcp.Name:
-		_, err = gcpconfig.GetSession(context.TODO())
+		_, err = gcpconfig.GetSession(ctx)
 		if err != nil {
 			return errors.Wrap(err, "creating GCP session")
 		}
